==> cscec5b-storecloud-api-3.0.1-20220818.092027-63-sources.jar: com/ejianc/business/storecloud/vo/ConfigProjectVO.java <==
package com.ejianc.business.storecloud.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设置表
 * 
 * @author generator
 * 
 */
public class ConfigProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer enabled; // 是否启用 1启用 0禁用
    private Integer initializeEnabled; // 是否初始化 1是 0否
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private String orgCode; // 组织编码
    private Long parentId; // 父级主键
    private String parentName; // 父级名称
    private Long parentCode; // 父级编码
    private String parentInnerCode;//父级内码
    

    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Integer getInitializeEnabled() {
        return initializeEnabled;
    }

    public void setInitializeEnabled(Integer initializeEnabled) {
        this.initializeEnabled = initializeEnabled;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }
    public Long getParentCode() {
        return parentCode;
    }

    public void setParentCode(Long parentCode) {
        this.parentCode = parentCode;
    }



}

==> cscec5b-storecloud-api-3.0.1-20220826.133311-117-sources.jar: com/ejianc/business/storecloud/vo/ConfigProjectVO.java <==
package com.ejianc.business.storecloud.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设置表
 *
 * @author generator
 *
 */
public class ConfigProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Integer enabled; // 是否启用 1启用 0禁用
    private Integer initializeEnabled; // 是否初始化  1是 0否
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private String orgCode; // 组织编码
    private Long parentId; // 父级主键
    private String parentName; // 父级名称
    private String parentCode; // 父级编码
    private String parentInnerCode; // 父级内码
    private String sourceId;// NC主键

    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public Integer getInitializeEnabled() {
        return initializeEnabled;
    }

    public void setInitializeEnabled(Integer initializeEnabled) {
        this.initializeEnabled = initializeEnabled;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public String getParentInnerCode() {
        return parentInnerCode;
    }

    public void setParentInnerCode(String parentInnerCode) {
        this.parentInnerCode = parentInnerCode;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
}
